==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/fi.js <==
/**
 * Finnish
 */

$.Editable.LANGS['fi'] = {
  translation: {
    "Bold": "Lihavointi",
    "Italic": "Kursivointi",
    "Underline": "Alleviivaus",
    "Strikethrough": "Yliviivaus",
    "Font Size": "Fonttikoko",
    "Color": "V\u00e4ri",
    "Background Color": "Taustan v\u00e4ri",
    "Text Color": "Tekstin v\u00e4ri",
    "Format Block": "Muotoilut",
    "Normal": "Normaali",
    "Paragraph": "Kappale",
    "Code": "Koodi",
    "Quote": "Lainauslohko",
    "Heading 1": "Otsikko 1",
    "Heading 2": "Otsikko 2",
    "Heading 3": "Otsikko 3",
    "Heading 4": "Otsikko 4",
    "Heading 5": "Otsikko 5",
    "Heading 6": "Otsikko 6",
    "Alignment": "Tasaus",
    "Align Left": "Tasaa vasemmalle",
    "Align Center": "Keskit\u00e4",
    "Align Right": "Tasaa oikealle",
    "Justify": "Tasaa",
    "Numbered List": "J\u00e4rjestetty lista",
    "Bulleted List": "J\u00e4rjest\u00e4m\u00e4t\u00f6n lista",
    "Indent Less": "Sisenn\u00e4",
    "Indent More": "Loitonna",
    "Select All": "Valitse kaikki",
    "Insert Link": "Lis\u00e4\u00e4 linkki",
    "Insert Image": "Lis\u00e4\u00e4 kuva",
    "Insert Video": "Lis\u00e4\u00e4 video",
    "Undo": "Peru",
    "Redo": "Tee uudelleen",
    "Show HTML": "N\u00e4yt\u00e4 HTML",
    "Float Left": "Vasen",
    "Float None": "Ei mit\u00e4\u00e4n",
    "Float Right": "Oikea",
    "Replace Image": "Vaihda kuva",
    "Remove Image": "Poista kuva",
    "Title": "Otsikko",
    "Insert image": "Lis\u00e4\u00e4 kuva",
    "Drop image": "Pudottaa kuva",
    "or click": "tai napsauta",
    "Enter URL": "Anna URL",
    "Please wait!": "Olkaa hyv\u00e4 odota!",
    "Are you sure? Image will be deleted.": "Oletko varma? Kuva poistetaan.",
    "UNLINK": "Poista linkki",
    "Open in new tab": "Avaa uudessa v\u00e4lilehdess\u00e4",
    "Type something": "Kirjoita jotain",
    "Cancel": "Peruuta",
    "OK": "Ok",
    "Manage images": "Hallita kuvia",
    "Delete": "Poistaa",
    "Font Family": "Fontti",
    "Insert Horizontal Line": "Lis\u00e4\u00e4 vaakasuora viiva"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.6.tar.gz: django-froala-editor-0.8.6/froala_editor/static/froala_editor/js/langs/fi.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Finnish
 */

$.Editable.LANGS['fi'] = {
  translation: {
    "Bold": "Lihavointi",
    "Italic": "Kursivointi",
    "Underline": "Alleviivaus",
    "Strikethrough": "Yliviivaus",
    "Font Size": "Fonttikoko",
    "Color": "V\u00e4ri",
    "Background Color": "Taustan v\u00e4ri",
    "Text Color": "Tekstin v\u00e4ri",
    "Format Block": "Muotoilut",
    "Normal": "Normaali",
    "Paragraph": "Kappale",
    "Code": "Koodi",
    "Quote": "Lainauslohko",
    "Heading 1": "Otsikko 1",
    "Heading 2": "Otsikko 2",
    "Heading 3": "Otsikko 3",
    "Heading 4": "Otsikko 4",
    "Heading 5": "Otsikko 5",
    "Heading 6": "Otsikko 6",
    "Alignment": "Tasaus",
    "Align Left": "Tasaa vasemmalle",
    "Align Center": "Keskit\u00e4",
    "Align Right": "Tasaa oikealle",
    "Justify": "Tasaa",
    "Numbered List": "J\u00e4rjestetty lista",
    "Bulleted List": "J\u00e4rjest\u00e4m\u00e4t\u00f6n lista",
    "Indent Less": "Sisenn\u00e4",
    "Indent More": "Loitonna",
    "Select All": "Valitse kaikki",
    "Insert Link": "Lis\u00e4\u00e4 linkki",
    "Insert Image": "Lis\u00e4\u00e4 kuva",
    "Insert Video": "Lis\u00e4\u00e4 video",
    "Undo": "Peru",
    "Redo": "Tee uudelleen",
    "Show HTML": "N\u00e4yt\u00e4 HTML",
    "Float Left": "Vasen",
    "Float None": "Ei mit\u00e4\u00e4n",
    "Float Right": "Oikea",
    "Replace Image": "Vaihda kuva",
    "Remove Image": "Poista kuva",
    "Title": "Otsikko",
    "Insert image": "Lis\u00e4\u00e4 kuva",
    "Drop image": "Pudottaa kuva",
    "or click": "tai napsauta",
    "Enter URL": "Anna URL",
    "Please wait!": "Olkaa hyv\u00e4 odota!",
    "Are you sure? Image will be deleted.": "Oletko varma? Kuva poistetaan.",
    "UNLINK": "Poista linkki",
    "Open in new tab": "Avaa uudessa v\u00e4lilehdess\u00e4",
    "Type something": "Kirjoita jotain",
    "Cancel": "Peruuta",
    "OK": "Ok",
    "Manage images": "Hallita kuvia",
    "Delete": "Poistaa",
    "Font Family": "Fontti",
    "Insert Horizontal Line": "Lis\u00e4\u00e4 vaakasuora viiva",
    "Table": "Taulukko",
    "Insert table": "Lis\u00e4\u00e4 taulukko",
    "Cell": "Solu",
    "Row": "Rivi",
    "Column": "Sarake",
    "Delete table": "Poista taulukko",
    "Insert cell before": "Lis\u00e4\u00e4 solu ennen",
    "Insert cell after": "Lis\u00e4\u00e4 solu j\u00e4lkeen",
    "Delete cell": "Poista solu",
    "Merge cells": "Yhdist\u00e4 solut",
    "Horizontal split": "Jaa vaakasuora",
    "Vertical split": "Jaa pystysuora",
    "Insert row above": "Lis\u00e4\u00e4 rivi ennen",
    "Insert row below": "Lis\u00e4\u00e4 rivi j\u00e4lkeen",
    "Delete row": "Poista rivi",
    "Insert column before": "Lis\u00e4\u00e4 sarake ennen",
    "Insert column after": "Lis\u00e4\u00e4 sarake j\u00e4lkeen",
    "Delete column": "Poista sarake"
  },
  direction: "ltr"
};
